# 금도 서버 환경 문서

## 📝 개요

이 저장소는 금도 서버의 Nginx 프록시 서버 정보와 Docker 환경 정보를 문서화한 저장소입니다.

## 🐳 Docker 환경

### 서버별 Docker 버전 현황

| 서버 이름 | Docker Engine 버전 | API 버전 | OS/Arch |
| :---- | :---- | :---- | :---- |
| gds-PowerEdge-R760xa | 28.0.4 | 1.48 | linux/amd64 |
| gds-PowerEdge-R820 | 27.3.1 | 1.47 | linux/amd64 |
| gds-PowerEdge-R820-2 | 27.1.1 | 1.46 | linux/amd64 |
| desktopserver | 27.0.3 | 1.46 | linux/amd64 |
| gds-PT620 | 20.10.11/26.0.2 | 1.41/1.45 | linux/amd64 |
| gds | 24.0.7 | 1.43 | linux/amd64 |

### 주요 Docker Compose 프로젝트

- **vnexa-abb-api**: API 서비스 (포트: 8000)
- **rvtouch3d-api**: 3D 터치 API 서비스 (포트: 3002, 3003, 8001, 9092, 5434, 6381)
- **jupyter_gpu_docker**: GPU 지원 Jupyter 서비스 (포트: 8888)
- **docker_3dp**: 3D 프린팅 서비스 (포트: 80, 3000, 3306, 8080, 8090, 2212)
- **docker_vnexa_api**: VNEXA API 서비스 (포트: 2213, 3001)
- **docker_metaverse**: 메타버스 서비스 (포트: 52530, 52532-52533, 53306, 2236)

## 🌐 Nginx 프록시 서버

### 주요 설정 파일

- **`nginx.conf`**: Nginx 프로세스의 동작 방식, 로그 형식, SSL/TLS 기본 설정 등 전역적인 설정
- **`/etc/nginx/sites-enabled/`**: 각 도메인 또는 서비스에 대한 구체적인 프록시 규칙

### 주요 프록시 서비스

#### 리버스 프록시 서비스
- **3D 프린팅 관련**: `3dp-nextcloud.geumdo.net`, `g3d.geumdo.net`, `sw3d.geumdo.net`
- **API 서비스**: `fastapi.geumdo.net`, `flaskapi.geumdo.net`, `vnexa-api.geumdo.net`
- **개발 도구**: `jupyter.geumdo.net`, `gitlab.geumdo.net`, `ollama.geumdo.net`
- **메일 서비스**: `mail.geumdo.net`

#### PHP-FPM 서비스
- **PHP 7.4**: 다수의 웹 애플리케이션 (예: `aifor.geumdo.net`, `dgei.geumdo.net`)
- **PHP 5.6**: 레거시 웹 애플리케이션 (예: `3dprinter.geumdo.net`, `sw3d.geumdo.net`)

### SSL/TLS 설정

- **Certbot 관리**: `proxy.geumdo.net`, `dip-zero.geumdo.net`, `mail.geumdo.net`
- **수동 관리**: `gdlab.co.kr`, `gbmax.or.kr`, `geumdo.net`, `max.or.kr`

## 🔒 보안 설정

- 모든 HTTPS 서비스는 HTTP to HTTPS 리다이렉트 적용
- 일치하는 도메인이 없는 HTTPS 요청은 444 응답으로 즉시 종료
- WebSocket 및 SSE 지원 서비스에 대한 특별 설정 적용

## 📚 상세 문서

- [Docker 환경 상세 리포트](Geumdo_Docker_환경_리포트_25.06.11_.md)
- [Nginx 프록시 설정 분석](nginx_proxy_analysis.md)
- [Docker 배포 가이드](docker_deployment_guide.md)
